<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AppOptionsDialog</name>
    <message>
        <source>App Options</source>
        <translation>Opzioni dell&apos;applicazione</translation>
    </message>
    <message>
        <source>Play sound when finished</source>
        <translation>Riproduci un suono al termine</translation>
    </message>
    <message>
        <source>Eject media when finished</source>
        <translation>Espelli il supporto al termine</translation>
    </message>
    <message>
        <source>Enable anonymous statistics (telemetry)</source>
        <translation>Abilita statistiche anonime (telemetria)</translation>
    </message>
    <message>
        <source>What is this?</source>
        <translation>Che cos&apos;è?</translation>
    </message>
    <message>
        <source>Disable warnings</source>
        <translation>Disabilita avvisi</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Disable warnings?</source>
        <translation>Disabilitare gli avvisi?</translation>
    </message>
    <message>
        <source>If you disable warnings, Raspberry Pi Imager will &lt;b&gt;not show confirmation prompts before writing images&lt;/b&gt;. You will still be required to &lt;b&gt;type the exact name&lt;/b&gt; when selecting a system drive.</source>
        <translation>Se disabiliti gli avvisi, Raspberry Pi Imager &lt;b&gt;non mostrerà richieste di conferma prima di scrivere le immagini&lt;/b&gt;. Sarà comunque necessario &lt;b&gt;digitare il nome esatto&lt;/b&gt; quando selezioni un&apos;unità di sistema.</translation>
    </message>
    <message>
        <source>Content Repository</source>
        <translation>Repository dei contenuti</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Close the options dialog without saving any changes</source>
        <translation>Chiudi la finestra delle opzioni senza salvare le modifiche</translation>
    </message>
    <message>
        <source>Save the selected options and apply them to Raspberry Pi Imager</source>
        <translation>Salva le opzioni selezionate e applicale a Raspberry Pi Imager</translation>
    </message>
    <message>
        <source>Keep warnings enabled and return to the options dialog</source>
        <translation>Mantieni gli avvisi abilitati e torna alle opzioni</translation>
    </message>
    <message>
        <source>Disable confirmation prompts before writing images, requiring only exact name entry for system drives</source>
        <translation>Disattiva le conferme prima della scrittura delle immagini, richiedendo solo l&apos;inserimento esatto del nome per le unità di sistema</translation>
    </message>
    <message>
        <source>Play an audio notification when the image write process completes</source>
        <translation>Riproduci una notifica audio quando il processo di scrittura termina</translation>
    </message>
    <message>
        <source>Automatically eject the storage device when the write process completes successfully</source>
        <translation>Espelli automaticamente il dispositivo di archiviazione al termine della scrittura</translation>
    </message>
    <message>
        <source>Send anonymous usage statistics to help improve Raspberry Pi Imager</source>
        <translation>Invia statistiche d&apos;uso anonime per contribuire a migliorare Raspberry Pi Imager</translation>
    </message>
    <message>
        <source>Skip confirmation dialogs before writing images (advanced users only)</source>
        <translation>Salta le finestre di conferma prima della scrittura delle immagini (solo utenti esperti)</translation>
    </message>
    <message>
        <source>Change the source of operating system images between official Raspberry Pi repository and custom sources</source>
        <translation>Cambia l&apos;origine delle immagini del sistema operativo tra il repository ufficiale Raspberry Pi e fonti personalizzate</translation>
    </message>
    <message>
        <source>Secure Boot RSA Key</source>
        <translation>Chiave RSA Secure Boot</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambia</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>Select an RSA 2048-bit private key for signing boot images in secure boot mode</source>
        <translation>Seleziona una chiave privata RSA 2048-bit per firmare le immagini di avvio in modalità Secure Boot</translation>
    </message>
    <message>
        <source>Select RSA Private Key</source>
        <translation>Seleziona chiave privata RSA</translation>
    </message>
    <message>
        <source>PEM Files (*.pem);;All Files (*)</source>
        <translation>File PEM (*.pem);;Tutti i file (*)</translation>
    </message>
    <message>
        <source>PEM Files (*.pem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AsyncCacheWriter</name>
    <message>
        <source>Cache write error: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonStrings</name>
    <message>
        <source>Only proceed if you fully understand the risks.</source>
        <translation>Procedi solo se comprendi pienamente i rischi.</translation>
    </message>
    <message>
        <source>Selecting the wrong drive will permanently erase data and can render your computer inoperable.</source>
        <translation>Selezionare l&apos;unità sbagliata cancellerà definitivamente i dati e può rendere il computer inutilizzabile.</translation>
    </message>
    <message>
        <source>System drives typically contain files essential to the operation of your computer, and may include your personal files (photos, videos, documents).</source>
        <translation>Le unità di sistema contengono in genere file essenziali per il funzionamento del computer e possono includere i tuoi file personali (foto, video, documenti).</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Tutti i file (*)</translation>
    </message>
    <message>
        <source>Image files (%1)</source>
        <translation>File immagine (%1)</translation>
    </message>
    <message>
        <source>Imager Repository Files (*.json)</source>
        <translation>Imager Repository Files (*.json)</translation>
    </message>
    <message>
        <source>Public Key files (*.pub)</source>
        <translation>File di chiave pubblica (*.pub)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Sfoglia</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Fine</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>Seleziona file immagine</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <source>Storage:</source>
        <translation>Archiviazione:</translation>
    </message>
    <message>
        <source>No device selected</source>
        <translation>Nessun dispositivo selezionato</translation>
    </message>
    <message>
        <source>No image selected</source>
        <translation>Nessuna immagine selezionata</translation>
    </message>
    <message>
        <source>No storage selected</source>
        <translation>Nessun dispositivo di archiviazione selezionato</translation>
    </message>
    <message>
        <source>Hostname configured</source>
        <translation>Hostname configurato</translation>
    </message>
    <message>
        <source>User account configured</source>
        <translation>Account utente configurato</translation>
    </message>
    <message>
        <source>SSH enabled</source>
        <translation>SSH abilitato</translation>
    </message>
    <message>
        <source>Wi‑Fi configured</source>
        <translation>Wi‑Fi configurato</translation>
    </message>
    <message>
        <source>Raspberry Pi Connect enabled</source>
        <translation>Raspberry Pi Connect abilitato</translation>
    </message>
    <message>
        <source>I2C enabled</source>
        <translation>I2C abilitato</translation>
    </message>
    <message>
        <source>SPI enabled</source>
        <translation>SPI abilitato</translation>
    </message>
    <message>
        <source>USB Gadget mode enabled</source>
        <translation>Modalità USB Gadget abilitata</translation>
    </message>
    <message>
        <source>1-Wire enabled</source>
        <translation>1-Wire abilitato</translation>
    </message>
    <message>
        <source>Serial configured</source>
        <translation>Seriale configurato</translation>
    </message>
    <message>
        <source>Localisation configured</source>
        <translation>Localizzazione configurata</translation>
    </message>
    <message>
        <source>Authorized keys files (authorized_keys)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmSystemDriveDialog</name>
    <message>
        <source>Size: %1</source>
        <translation>Dimensione: %1</translation>
    </message>
    <message>
        <source>Mounted as: %1</source>
        <translation>Montato come: %1</translation>
    </message>
    <message>
        <source>Not mounted</source>
        <translation>Non montato</translation>
    </message>
    <message>
        <source>To continue, type the exact drive name below:</source>
        <translation>Per continuare, digita esattamente il nome dell&apos;unità qui sotto:</translation>
    </message>
    <message>
        <source>Type drive name exactly as shown above</source>
        <translation>Digita il nome dell&apos;unità esattamente come mostrato sopra</translation>
    </message>
    <message>
        <source>CANCEL</source>
        <translation>ANNULLA</translation>
    </message>
    <message>
        <source>CONTINUE</source>
        <translation>CONTINUA</translation>
    </message>
    <message>
        <source>Cancel operation and return to storage selection to choose a different device</source>
        <translation>Annulla l&apos;operazione e torna alla selezione dello storage per scegliere un dispositivo diverso</translation>
    </message>
    <message>
        <source>Proceed to write the image to this system drive after confirming the drive name</source>
        <translation>Procedi a scrivere l&apos;immagine su questa unità di sistema dopo aver confermato il nome dell&apos;unità</translation>
    </message>
    <message>
        <source>Drive information</source>
        <translation>Informazioni sull&apos;unità</translation>
    </message>
    <message>
        <source>Drive name to type: %1</source>
        <translation>Nome dell&apos;unità da digitare: %1</translation>
    </message>
    <message>
        <source>Drive name input. Type exactly: %1. %2</source>
        <translation>Inserimento nome unità. Digita esattamente: %1. %2</translation>
    </message>
</context>
<context>
    <name>ConfirmUnfilterDialog</name>
    <message>
        <source>By disabling system drive filtering, &lt;b&gt;system drives will be shown&lt;/b&gt; in the list.</source>
        <translation>Disabilitando il filtro delle unità di sistema, &lt;b&gt;le unità di sistema verranno mostrate&lt;/b&gt; nell&apos;elenco.</translation>
    </message>
    <message>
        <source>KEEP FILTER ON</source>
        <translation>MANTIENI FILTRO ATTIVO</translation>
    </message>
    <message>
        <source>SHOW SYSTEM DRIVES</source>
        <translation>MOSTRA UNITÀ DI SISTEMA</translation>
    </message>
    <message>
        <source>Keep system drives hidden to prevent accidental damage to your operating system</source>
        <translation>Mantieni nascoste le unità di sistema per evitare danni accidentali al sistema operativo</translation>
    </message>
    <message>
        <source>Remove the safety filter and display system drives in the storage device list</source>
        <translation>Rimuovi il filtro di sicurezza e mostra le unità di sistema nell&apos;elenco dei dispositivi di archiviazione</translation>
    </message>
</context>
<context>
    <name>DeviceSelectionStep</name>
    <message>
        <source>Select your Raspberry Pi device</source>
        <translation>Seleziona il tuo dispositivo Raspberry Pi</translation>
    </message>
    <message>
        <source>Device selection list</source>
        <translation>Elenco dispositivi</translation>
    </message>
    <message>
        <source>No devices</source>
        <translation>Nessun dispositivo</translation>
    </message>
    <message>
        <source>1 device</source>
        <translation>1 dispositivo</translation>
    </message>
    <message>
        <source>%1 devices</source>
        <translation>%1 dispositivi</translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select</source>
        <translation>Usa le frecce per navigare, Invio o Spazio per selezionare</translation>
    </message>
</context>
<context>
    <name>DoneStep</name>
    <message>
        <source>Your choices:</source>
        <translation>Le tue scelte:</translation>
    </message>
    <message>
        <source>The storage device was ejected automatically. You can now remove it safely.</source>
        <translation>Il dispositivo di archiviazione è stato espulso automaticamente. Ora puoi rimuoverlo in sicurezza.</translation>
    </message>
    <message>
        <source>Please eject the storage device before removing it from your computer.</source>
        <translation>Espelli il dispositivo di archiviazione prima di rimuoverlo dal computer.</translation>
    </message>
    <message>
        <source>Write Another</source>
        <translation>Scrivi un altro</translation>
    </message>
    <message>
        <source>Write complete!</source>
        <translation>Scrittura completata!</translation>
    </message>
    <message>
        <source>Customisations applied:</source>
        <translation>Personalizzazioni applicate:</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Operating system:</source>
        <translation>Sistema operativo:</translation>
    </message>
    <message>
        <source>Storage:</source>
        <translation>Archiviazione:</translation>
    </message>
    <message>
        <source>Reboot the system to apply changes</source>
        <translation>Riavvia il sistema per applicare le modifiche</translation>
    </message>
    <message>
        <source>Close Raspberry Pi Imager and exit the application</source>
        <translation>Chiudi Raspberry Pi Imager ed esci dall&apos;applicazione</translation>
    </message>
    <message>
        <source>Return to storage selection to write the same image to another storage device</source>
        <translation>Torna alla selezione dello storage per scrivere la stessa immagine su un altro dispositivo</translation>
    </message>
    <message>
        <source>customization</source>
        <translation>personalizzazione</translation>
    </message>
    <message>
        <source>customizations</source>
        <translation>personalizzazioni</translation>
    </message>
</context>
<context>
    <name>DownloadExtractThread</name>
    <message>
        <source>Error extracting archive: %1</source>
        <translation>Errore estrazione archivio: %1</translation>
    </message>
    <message>
        <source>Error mounting FAT32 partition</source>
        <translation>Errore montaggio partizione FAT32</translation>
    </message>
    <message>
        <source>Operating system did not mount FAT32 partition</source>
        <translation>Il sistema operativo non ha montato la partizione FAT32</translation>
    </message>
    <message>
        <source>Error changing to directory &apos;%1&apos;</source>
        <translation>Errore passaggio a cartella &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
        <translation>Errore lettura dallo storage.&lt;br&gt;La scheda SD potrebbe essere danneggiata.</translation>
    </message>
    <message>
        <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
        <translation>Verifica scrittura fallita.&lt;br&gt;Il contenuto della SD è differente da quello che vi è stato scritto.</translation>
    </message>
</context>
<context>
    <name>DownloadThread</name>
    <message>
        <source>Please verify if &apos;Raspberry Pi Imager&apos; is allowed access to &apos;removable volumes&apos; in privacy settings (under &apos;files and folders&apos; or alternatively give it &apos;full disk access&apos;).</source>
        <translation>Verifica se a &apos;Raspberry Pi Imager&apos; è consentito l&apos;accesso a &apos;volumi rimovibili&apos; nelle impostazioni privacy (in &apos;file e cartelle&apos; o in alternativa concedi &apos;accesso completo al disco&apos;).</translation>
    </message>
    <message>
        <source>Cannot open storage device &apos;%1&apos;.</source>
        <translation>Impossibile aprire dispositivo storage &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Write error while zero&apos;ing out MBR</source>
        <translation>Errore scrittura durante azzeramento MBR</translation>
    </message>
    <message>
        <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
        <translation>Errore di scrittura durante il tentativo di azzerare l&apos;ultima parte della scheda.&lt;br&gt;La scheda potrebbe riportare una capacità maggiore di quella reale (possibile contraffazione).</translation>
    </message>
    <message>
        <source>Error downloading: %1</source>
        <translation>Errore download: %1</translation>
    </message>
    <message>
        <source>Access denied error while writing file to disk.</source>
        <translation>Errore accesso negato durante la scrittura del file su disco.</translation>
    </message>
    <message>
        <source>Error writing to storage (while flushing)</source>
        <translation>Errore scrittura nello storage (durante flushing)</translation>
    </message>
    <message>
        <source>Error writing to storage (while fsync)</source>
        <translation>Errore scrittura nello storage (durante fsync)</translation>
    </message>
    <message>
        <source>Error writing first block (partition table)</source>
        <translation>Errore scrittura primo blocco (tabella partizione)</translation>
    </message>
    <message>
        <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
        <translation>Errore lettura dallo storage.&lt;br&gt;La scheda SD potrebbe essere danneggiata.</translation>
    </message>
    <message>
        <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
        <translation>Verifica scrittura fallita.&lt;br&gt;Il contenuto della SD è differente da quello che vi è stato scritto.</translation>
    </message>
    <message>
        <source>Cached file is corrupt. SHA256 hash does not match expected value.&lt;br&gt;The cache file will be removed and the download will restart.</source>
        <translation>Il file memorizzata nella cache è corrotto.&lt;br&gt;L&apos;hash SHA256 non corrisponde al valore previsto.&lt;br&gt; Il file cache verrà rimosso ed il download si riavvierà.</translation>
    </message>
    <message>
        <source>Local file is corrupt or has incorrect SHA256 hash.&lt;br&gt;Expected: %1&lt;br&gt;Actual: %2</source>
        <translation>Il file locale è corrotto o ha l&apos;hash SHA256 errato. &lt;br&gt;Previsto: %1 &lt;br&gt;Effettivo: %2</translation>
    </message>
    <message>
        <source>Download appears to be corrupt. SHA256 hash does not match.&lt;br&gt;Expected: %1&lt;br&gt;Actual: %2&lt;br&gt;Please check your network connection and try again.</source>
        <translation>Il download sembra essere corrotto.&lt;br&gt;L&apos;hash SHA256 non corrisponde.&lt;br&gt;Previsto: %1&lt;br&gt;Effettivo: %2&lt;br&gt;Controlla la connessione di rete e riprova.</translation>
    </message>
    <message>
        <source>Controlled Folder Access seems to be enabled. Please add rpi-imager.exe to the list of allowed apps and try again.</source>
        <translation>L&apos;accesso controllato alla cartella sembra sia abilitato. Aggiungi rpi-imager.exe all&apos;elenco delle app consentite e riprova.</translation>
    </message>
    <message>
        <source>Error: Multiple partitions found on disk. Please ensure the disk is completely clean.</source>
        <translation>Errore: Trovate più partizioni sul disco. Assicurati che il disco sia completamente pulito.</translation>
    </message>
    <message>
        <source>The disk may be write-protected or in use by another application. Please ensure the disk is not mounted and try again.</source>
        <translation>Il disco potrebbe essere protetto da scrittura o in uso da un&apos;altra applicazione. Assicurati che il disco non sia montato e riprova.</translation>
    </message>
    <message>
        <source>Disk is full. Please use a larger storage device.</source>
        <translation>Disco pieno. Usa un dispositivo di archiviazione più capiente.</translation>
    </message>
    <message>
        <source>The disk is write-protected. Please check if the disk has a physical write-protect switch or is read-only.</source>
        <translation>Il disco è protetto da scrittura. Verifica se il disco ha un interruttore fisico di protezione da scrittura o è in sola lettura.</translation>
    </message>
    <message>
        <source>Media error detected. The storage device may be damaged or counterfeit. Please try a different device.</source>
        <translation>Rilevato errore del supporto. Il dispositivo di archiviazione potrebbe essere danneggiato o contraffatto. Prova con un altro dispositivo.</translation>
    </message>
    <message>
        <source>Invalid disk parameter. The storage device may not be properly recognized. Please try reconnecting the device.</source>
        <translation>Parametro disco non valido. Il dispositivo di archiviazione potrebbe non essere riconosciuto correttamente. Prova a ricollegare il dispositivo.</translation>
    </message>
    <message>
        <source>I/O device error. The storage device may have been disconnected or is malfunctioning.</source>
        <translation>Errore dispositivo I/O. Il dispositivo di archiviazione potrebbe essere stato scollegato o essere guasto.</translation>
    </message>
    <message>
        <source>Error opening disk device &apos;%1&apos;</source>
        <translation>Errore nell&apos;apertura del dispositivo disco &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error getting device size</source>
        <translation>Errore durante l&apos;ottenimento della dimensione del dispositivo</translation>
    </message>
    <message>
        <source>Error writing to storage device. Please check if the device is writable, has sufficient space, and is not write-protected.</source>
        <translation>Errore di scrittura sul dispositivo di archiviazione. Verifica che il dispositivo sia scrivibile, abbia spazio sufficiente e non sia protetto da scrittura.</translation>
    </message>
    <message>
        <source>Unmounting drive...</source>
        <translation>Smontaggio unità...</translation>
    </message>
    <message>
        <source>Opening drive...</source>
        <translation>Apertura unità...</translation>
    </message>
    <message>
        <source>Discarding existing data on drive...</source>
        <translation>Eliminazione dei dati esistenti sull&apos;unità...</translation>
    </message>
    <message>
        <source>Zero&apos;ing out first and last MB of drive...</source>
        <translation>Azzeramento del primo e dell&apos;ultimo MB dell&apos;unità...</translation>
    </message>
    <message>
        <source>Starting download...</source>
        <translation>Avvio download...</translation>
    </message>
    <message>
        <source>Writing image...</source>
        <translation>Scrittura immagine...</translation>
    </message>
    <message>
        <source>Customising OS...</source>
        <translation>Personalizzazione del sistema operativo...</translation>
    </message>
    <message>
        <source>Cannot open storage device &apos;%1&apos;. Please run with elevated privileges (sudo).</source>
        <translation>Impossibile aprire il dispositivo di archiviazione &apos;%1&apos;. Esegui con privilegi elevati (sudo).</translation>
    </message>
    <message>
        <source>Creating signed boot image...</source>
        <translation>Creazione dell&apos;immagine di avvio firmata...</translation>
    </message>
    <message>
        <source>Failed to create secure boot files</source>
        <translation>Creazione dei file di Secure Boot non riuscita</translation>
    </message>
    <message>
        <source>No RSA key configured for secure boot. Please select a key in App Options.</source>
        <translation>Nessuna chiave RSA configurata per il Secure Boot. Seleziona una chiave nelle Opzioni dell&apos;app.</translation>
    </message>
    <message>
        <source>RSA key file not found: %1</source>
        <translation>File della chiave RSA non trovato: %1</translation>
    </message>
    <message>
        <source>Extracting boot partition files...</source>
        <translation>Estrazione dei file della partizione di avvio...</translation>
    </message>
    <message>
        <source>Failed to extract boot partition files</source>
        <translation>Impossibile estrarre i file della partizione di avvio</translation>
    </message>
    <message>
        <source>No boot files found to package</source>
        <translation>Nessun file di avvio trovato da impacchettare</translation>
    </message>
    <message>
        <source>Failed to create temporary directory</source>
        <translation>Impossibile creare la cartella temporanea</translation>
    </message>
    <message>
        <source>Creating boot.img...</source>
        <translation>Creazione di boot.img...</translation>
    </message>
    <message>
        <source>Failed to create boot.img</source>
        <translation>Impossibile creare boot.img</translation>
    </message>
    <message>
        <source>Signing boot image...</source>
        <translation>Firma dell&apos;immagine di avvio...</translation>
    </message>
    <message>
        <source>Failed to generate boot.sig</source>
        <translation>Impossibile generare boot.sig</translation>
    </message>
    <message>
        <source>Failed to read boot.img</source>
        <translation>Impossibile leggere boot.img</translation>
    </message>
    <message>
        <source>Failed to read boot.sig</source>
        <translation>Impossibile leggere boot.sig</translation>
    </message>
    <message>
        <source>Cleaning up boot partition...</source>
        <translation>Pulizia della partizione di avvio...</translation>
    </message>
    <message>
        <source>Syncing deletions to disk...</source>
        <translation>Sincronizzazione delle eliminazioni su disco...</translation>
    </message>
    <message>
        <source>Writing signed boot files...</source>
        <translation>Scrittura dei file di avvio firmati...</translation>
    </message>
    <message>
        <source>Failed to write secure boot files: %1</source>
        <translation>Impossibile scrivere i file di Secure Boot: %1</translation>
    </message>
    <message>
        <source>Unmounting volumes...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cleaning disk...</source>
        <translation type="unfinished">Pulizia del disco...</translation>
    </message>
    <message>
        <source>Cleaning disk (legacy method)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing customization files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to allocate buffer for MBR zeroing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DriveFormatThread</name>
    <message>
        <source>Error opening device for formatting</source>
        <translation>Errore apertura dispositivo durante la formattazione</translation>
    </message>
    <message>
        <source>Error writing to device during formatting</source>
        <translation>Errore scrittura dispositivo durante la formattazione</translation>
    </message>
    <message>
        <source>Error seeking on device during formatting</source>
        <translation>Errore ricerca dispositivo durante la formattazione</translation>
    </message>
    <message>
        <source>Invalid parameters for formatting</source>
        <translation>Parametro non valido per la formattazione</translation>
    </message>
    <message>
        <source>Insufficient space on device</source>
        <translation>Spazio insufficiente nel dispositivo</translation>
    </message>
    <message>
        <source>Unknown formatting error</source>
        <translation>Errore formattazione sconosciuto</translation>
    </message>
    <message>
        <source>Preparing disk for formatting...</source>
        <translation>Preparazione del disco per la formattazione...</translation>
    </message>
    <message>
        <source>Cleaning disk...</source>
        <translation>Pulizia del disco...</translation>
    </message>
    <message>
        <source>Writing filesystem...</source>
        <translation>Scrittura del filesystem...</translation>
    </message>
    <message>
        <source>Cannot format device: insufficient permissions. Please run with elevated privileges (sudo).</source>
        <translation>Impossibile formattare il dispositivo: permessi insufficienti. Esegui con privilegi elevati (sudo).</translation>
    </message>
</context>
<context>
    <name>HWListModel</name>
    <message>
        <source>CHOOSE DEVICE</source>
        <translation>SCEGLI DISPOSITIVO</translation>
    </message>
</context>
<context>
    <name>HostnameCustomizationStep</name>
    <message>
        <source>A hostname is a unique name that identifies your Raspberry Pi on the network. It should contain only letters, numbers, and hyphens.</source>
        <translation>Un hostname è un nome univoco che identifica il tuo Raspberry Pi sulla rete. Deve contenere solo lettere, numeri e trattini.</translation>
    </message>
    <message>
        <source>Customisation: Choose hostname</source>
        <translation>Personalizzazione: Scegli l&apos;hostname</translation>
    </message>
    <message>
        <source>Enter your hostname</source>
        <translation>Inserisci l&apos;hostname</translation>
    </message>
    <message>
        <source>Save hostname and continue to next customisation step</source>
        <translation>Salva l&apos;hostname e continua al passaggio successivo</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
</context>
<context>
    <name>IfAndFeaturesCustomizationStep</name>
    <message>
        <source>Enable hardware interfaces and connectivity options.</source>
        <translation>Abilita interfacce hardware e opzioni di connettività.</translation>
    </message>
    <message>
        <source>Interfaces</source>
        <translation>Interfacce</translation>
    </message>
    <message>
        <source>Enable SPI</source>
        <translation>Abilita SPI</translation>
    </message>
    <message>
        <source>Enable Serial:</source>
        <translation>Abilita seriale:</translation>
    </message>
    <message>
        <source>Features</source>
        <translation>Funzionalità</translation>
    </message>
    <message>
        <source>Enable USB Gadget Mode</source>
        <translation>Abilita modalità USB Gadget</translation>
    </message>
    <message>
        <source>Learn more about USB Gadget Mode</source>
        <translation>Scopri di più sulla modalità USB Gadget</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>Console</translation>
    </message>
    <message>
        <source>USB Gadget Mode can change how your device behaves and may impact connectivity and host interaction.</source>
        <translation>La modalità USB Gadget può modificare il comportamento del dispositivo e influire sulla connettività e sull&apos;interazione con l&apos;host.</translation>
    </message>
    <message>
        <source>Please review the &lt;a href=&apos;%1&apos;&gt;documentation&lt;/a&gt; before proceeding.</source>
        <translation>Consulta la &lt;a href=&apos;%1&apos;&gt;documentazione&lt;/a&gt; prima di procedere.</translation>
    </message>
    <message>
        <source>Only continue if you are sure you know what you are doing.</source>
        <translation>Continua solo se sei certo di sapere cosa stai facendo.</translation>
    </message>
    <message>
        <source>I understand, continue</source>
        <translation>Ho capito, continua</translation>
    </message>
    <message>
        <source>Customisation: Interfaces &amp; Features</source>
        <translation>Personalizzazione: Interfacce e funzionalità</translation>
    </message>
    <message>
        <source>Enable I2C</source>
        <translation>Abilita I2C</translation>
    </message>
    <message>
        <source>Enable 1-Wire</source>
        <translation>Abilita 1-Wire</translation>
    </message>
    <message>
        <source>Enable the I2C (Inter-Integrated Circuit) interface for connecting sensors and other low-speed peripherals</source>
        <translation>Abilita l&apos;interfaccia I2C (Inter-Integrated Circuit) per collegare sensori e altre periferiche a bassa velocità</translation>
    </message>
    <message>
        <source>Enable the SPI (Serial Peripheral Interface) for high-speed communication with displays and sensors</source>
        <translation>Abilita l&apos;interfaccia SPI (Serial Peripheral Interface) per comunicazioni ad alta velocità con display e sensori</translation>
    </message>
    <message>
        <source>Enable the 1-Wire interface for connecting temperature sensors and other Dallas/Maxim devices</source>
        <translation>Abilita l&apos;interfaccia 1-Wire per collegare sensori di temperatura e altri dispositivi Dallas/Maxim</translation>
    </message>
    <message>
        <source>Enable USB device mode to use your Raspberry Pi as a USB peripheral for networking and storage</source>
        <translation>Abilita la modalità dispositivo USB per usare il Raspberry Pi come periferica USB per rete e archiviazione</translation>
    </message>
    <message>
        <source>Save interface and feature settings and continue to writing step</source>
        <translation>Salva le impostazioni di interfacce e funzionalità e continua alla scrittura</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Configure the serial interface: Disabled, Default (system decides), Console &amp; Hardware (both console and UART), Hardware (UART only), or Console (console only on supported devices).</source>
        <translation>Configura l&apos;interfaccia seriale: Disabilitata, Predefinita (decide il sistema), Console e Hardware (console e UART), Solo hardware (solo UART) o Solo console (solo console nei dispositivi supportati).</translation>
    </message>
    <message>
        <source>USB Gadget Mode Warning</source>
        <translation>Avviso modalità USB Gadget</translation>
    </message>
    <message>
        <source>Please review the documentation before proceeding.</source>
        <translation>Consulta la documentazione prima di procedere.</translation>
    </message>
    <message>
        <source>Cancel and return to the interfaces and features settings without enabling USB Gadget Mode</source>
        <translation>Annulla e torna alle impostazioni di interfacce e funzionalità senza abilitare la modalità USB Gadget</translation>
    </message>
    <message>
        <source>Confirm that you understand the risks and continue with USB Gadget Mode enabled</source>
        <translation>Conferma di aver compreso i rischi e continua con la modalità USB Gadget abilitata</translation>
    </message>
    <message>
        <source>This button will be enabled after 2 seconds</source>
        <translation>Questo pulsante sarà abilitato dopo 2 secondi</translation>
    </message>
</context>
<context>
    <name>ImComboBox</name>
    <message>
        <source>Type to search: &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(press again to cycle)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImFileDialog</name>
    <message>
        <source>Select File</source>
        <translation>Seleziona file</translation>
    </message>
    <message>
        <source>Enter path or URL…</source>
        <translation>Inserisci percorso o URL…</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Cartelle</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Removable drives</source>
        <translation>Unità rimovibili</translation>
    </message>
    <message>
        <source>Go up a folder</source>
        <translation>Sali di una cartella</translation>
    </message>
    <message>
        <source>No files in this folder</source>
        <translation>Nessun file in questa cartella</translation>
    </message>
    <message>
        <source>Folder: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter filename…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Navigate to a folder using the panel on the left,
or type a path in the address bar above.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
</context>
<context>
    <name>ImOptionButton</name>
    <message>
        <source>Opens in browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImOptionPill</name>
    <message>
        <source>Opens in browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImPasswordField</name>
    <message>
        <source>Password is visible. Press F2 to hide.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is hidden. Press F2 to show.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is currently visible. Activate to hide it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is currently hidden. Activate to show it.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImPopup</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImSaveFileDialog</name>
    <message>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImTextField</name>
    <message>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
</context>
<context>
    <name>ImageWriter</name>
    <message>
        <source>Input file is not a valid disk image.&lt;br&gt;File size %1 bytes is not a multiple of 512 bytes.</source>
        <translation>Il file di input non è un&apos;immagine disco valida.&lt;br&gt;La dimensione del file di %1 byte non è un multiplo di 512 byte.</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>Seleziona immagine</translation>
    </message>
    <message>
        <source>STP is enabled on your Ethernet switch. Getting IP will take long time.</source>
        <translation>STP è abilitato sullo switch Ethernet. Ottenere l&apos;IP richiederà molto tempo.</translation>
    </message>
    <message>
        <source>Storage capacity is not large enough.&lt;br&gt;Needs to be at least %1.</source>
        <translation>La capacità di archiviazione non è sufficiente.&lt;br&gt;Deve essere almeno %1.</translation>
    </message>
    <message>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message>
        <source>%1.%2 %3</source>
        <translation>%1.%2 %3</translation>
    </message>
    <message>
        <source>Unknown precondition failure.</source>
        <translation>Errore sconosciuto sui prerequisiti.</translation>
    </message>
    <message>
        <source>Cannot start write. %1</source>
        <translation>Impossibile avviare la scrittura. %1</translation>
    </message>
    <message>
        <source>Source file not found: %1</source>
        <translation>File sorgente non trovato: %1</translation>
    </message>
    <message>
        <source>Source is not a regular file: %1</source>
        <translation>La sorgente non è un file: %1</translation>
    </message>
    <message>
        <source>Source file is not readable: %1</source>
        <translation>Il file sorgente non è leggibile: %1</translation>
    </message>
    <message>
        <source>image</source>
        <translation>immagine</translation>
    </message>
    <message>
        <source>storage device</source>
        <translation>dispositivo di archiviazione</translation>
    </message>
    <message>
        <source>valid storage device (device no longer available)</source>
        <translation>dispositivo di archiviazione valido (dispositivo non più disponibile)</translation>
    </message>
    <message>
        <source>No %1 selected.</source>
        <translation>Nessun %1 selezionato.</translation>
    </message>
    <message>
        <source> or </source>
        <translation> o </translation>
    </message>
    <message>
        <source>Save Performance Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JSON files (*.json);;All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeychainPermissionDialog</name>
    <message>
        <source>Keychain Access</source>
        <translation>Accesso Portachiavi</translation>
    </message>
    <message>
        <source>Would you like to prefill the Wi‑Fi password from the system keychain?</source>
        <translation>Vuoi precompilare la password Wi‑Fi dal portachiavi di sistema?</translation>
    </message>
    <message>
        <source>This will require administrator authentication on macOS.</source>
        <translation>Su macOS sarà necessaria l&apos;autenticazione dell&apos;amministratore.</translation>
    </message>
    <message>
        <source>Skip keychain access and manually enter the Wi-Fi password</source>
        <translation>Salta l&apos;accesso al portachiavi e inserisci manualmente la password Wi‑Fi</translation>
    </message>
    <message>
        <source>Retrieve the Wi-Fi password from the system keychain using administrator authentication</source>
        <translation>Recupera la password Wi‑Fi dal portachiavi di sistema usando l&apos;autenticazione amministratore</translation>
    </message>
</context>
<context>
    <name>LanguageSelectionStep</name>
    <message>
        <source>Welcome</source>
        <translation>Benvenuto</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Lingua:</translation>
    </message>
    <message>
        <source>Choose your language for Raspberry Pi Imager</source>
        <translation>Scegli la tua lingua per Raspberry Pi Imager</translation>
    </message>
    <message>
        <source>Select the language for the Raspberry Pi Imager interface</source>
        <translation>Seleziona la lingua dell&apos;interfaccia di Raspberry Pi Imager</translation>
    </message>
</context>
<context>
    <name>LocalFileExtractThread</name>
    <message>
        <source>Error opening image file</source>
        <translation>Errore durante l&apos;apertura del file immagine</translation>
    </message>
    <message>
        <source>Error reading from image file</source>
        <translation>Errore lettura file immagine</translation>
    </message>
    <message>
        <source>Error writing to device</source>
        <translation>Errore scrittura file immagine</translation>
    </message>
    <message>
        <source>Failed to read complete image file</source>
        <translation>Impossibile leggere il file immagine completo</translation>
    </message>
    <message>
        <source>Opening image file...</source>
        <translation>Apertura del file immagine...</translation>
    </message>
    <message>
        <source>Starting extraction...</source>
        <translation>Avvio estrazione...</translation>
    </message>
</context>
<context>
    <name>LocaleCustomizationStep</name>
    <message>
        <source>Keyboard layout:</source>
        <translation>Layout tastiera:</translation>
    </message>
    <message>
        <source>Time zone:</source>
        <translation>Fuso orario:</translation>
    </message>
    <message>
        <source>Customisation: Localisation</source>
        <translation>Personalizzazione: Localizzazione</translation>
    </message>
    <message>
        <source>Select your location for suggested time zone and keyboard layout</source>
        <translation>Seleziona la tua posizione per suggerire fuso orario e layout tastiera</translation>
    </message>
    <message>
        <source>Capital city:</source>
        <translation>Città capitale:</translation>
    </message>
    <message>
        <source>Save localisation settings and continue to next customisation step</source>
        <translation>Salva le impostazioni di localizzazione e continua al passaggio successivo</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Choose your nearest capital city. This will automatically recommend the correct time zone and keyboard layout for your region, and set the wireless regulatory domain for your country&apos;s Wi-Fi regulations.</source>
        <translation>Scegli la capitale più vicina. Questo consiglierà automaticamente il fuso orario e il layout tastiera corretti per la tua regione e imposterà il dominio regolatorio wireless in base alle normative Wi‑Fi del tuo paese.</translation>
    </message>
    <message>
        <source>Choose your time zone so your Raspberry Pi displays the correct local time. This is automatically recommended based on your capital city selection, but you can change it if the suggestion is incorrect.</source>
        <translation>Scegli il tuo fuso orario affinché il Raspberry Pi mostri l&apos;ora corretta. È consigliato automaticamente in base alla capitale selezionata, ma puoi modificarlo se la proposta non è corretta.</translation>
    </message>
    <message>
        <source>Choose your keyboard layout so keys produce the correct characters when typing. This is automatically recommended based on your capital city selection, but you can change it if you use a different keyboard layout.</source>
        <translation>Scegli il layout della tastiera affinché i tasti producano i caratteri corretti durante la digitazione. È consigliato automaticamente in base alla capitale selezionata, ma puoi cambiarlo se usi un layout diverso.</translation>
    </message>
</context>
<context>
    <name>MacFile</name>
    <message>
        <source>Raspberry Pi Imager needs to access the disk to write the image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NativeFileDialog</name>
    <message>
        <source>File type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OSListModel</name>
    <message>
        <source>Recommended</source>
        <translation>Raccomandato</translation>
    </message>
</context>
<context>
    <name>OSSelectionStep</name>
    <message>
        <source>Local - %1</source>
        <translation>Locale - %1</translation>
    </message>
    <message>
        <source>Cached on your computer</source>
        <translation>Memorizzato temporaneamente nel computer</translation>
    </message>
    <message>
        <source>Local file</source>
        <translation>File locale</translation>
    </message>
    <message>
        <source>Online - %1 download</source>
        <translation>Online - da scaricare %1</translation>
    </message>
    <message>
        <source>Go back to main menu</source>
        <translation>Torna al menu principale</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>Seleziona file immagine</translation>
    </message>
    <message>
        <source>Choose operating system</source>
        <translation>Scegli il sistema operativo</translation>
    </message>
    <message>
        <source>Select an operating system to install on your Raspberry Pi</source>
        <translation>Seleziona un sistema operativo da installare sul tuo Raspberry Pi</translation>
    </message>
    <message>
        <source>Operating system list</source>
        <translation>Elenco dei sistemi operativi</translation>
    </message>
    <message>
        <source>No operating systems</source>
        <translation>Nessun sistema operativo</translation>
    </message>
    <message>
        <source>1 operating system</source>
        <translation>1 sistema operativo</translation>
    </message>
    <message>
        <source>%1 operating systems</source>
        <translation>%1 sistemi operativi</translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select</source>
        <translation>Usa le frecce per navigare, Invio o Spazio per selezionare</translation>
    </message>
    <message>
        <source>Operating system category</source>
        <translation>Categoria sistema operativo</translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select, Left arrow to go back</source>
        <translation>Usa le frecce per navigare, Invio o Spazio per selezionare, Freccia sinistra per tornare indietro</translation>
    </message>
    <message>
        <source>Released: %1</source>
        <translation>Rilasciato: %1</translation>
    </message>
</context>
<context>
    <name>PiConnectCustomizationStep</name>
    <message>
        <source>Customisation: Raspberry Pi Connect</source>
        <translation>Personalizzazione: Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>Enable Raspberry Pi Connect</source>
        <translation>Abilita Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>What is Raspberry Pi Connect?</source>
        <translation>Che cos&apos;è Raspberry Pi Connect?</translation>
    </message>
    <message>
        <source>Open Raspberry Pi Connect</source>
        <translation>Apri Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>Token received from browser</source>
        <translation>Token ricevuto dal browser</translation>
    </message>
    <message>
        <source>Open the Raspberry Pi Connect website in your browser to sign in and receive an authentication token</source>
        <translation>Apri il sito di Raspberry Pi Connect nel browser per accedere e ricevere un token di autenticazione</translation>
    </message>
    <message>
        <source>Enable secure remote access to your Raspberry Pi through the Raspberry Pi Connect cloud service</source>
        <translation>Abilita l&apos;accesso remoto sicuro al tuo Raspberry Pi tramite il servizio cloud Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>Save Raspberry Pi Connect settings and continue to next customisation step</source>
        <translation>Salva le impostazioni di Raspberry Pi Connect e continua al passaggio successivo</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Enter or paste the authentication token from Raspberry Pi Connect. The token will be automatically filled if you use the &apos;Open Raspberry Pi Connect&apos; button to sign in.</source>
        <translation>Inserisci o incolla il token di autenticazione di Raspberry Pi Connect. Il token verrà compilato automaticamente se usi il pulsante &apos;Apri Raspberry Pi Connect&apos; per accedere.</translation>
    </message>
    <message>
        <source>Waiting for token (%1s)</source>
        <translation>In attesa del token (%1s)</translation>
    </message>
    <message>
        <source>Paste token here</source>
        <translation>Incolla qui il token</translation>
    </message>
    <message>
        <source>Invalid Token</source>
        <translation>Token non valido</translation>
    </message>
    <message>
        <source>The token you entered is not valid. Please check the token and try again, or use the &apos;Open Raspberry Pi Connect&apos; button to get a valid token.</source>
        <translation>Il token inserito non è valido. Controlla il token e riprova, oppure usa il pulsante &apos;Apri Raspberry Pi Connect&apos; per ottenerne uno valido.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Close this dialog and return to the token field</source>
        <translation>Chiudi questa finestra e torna al campo del token</translation>
    </message>
    <message>
        <source>Authentication token:</source>
        <translation>Token di autenticazione:</translation>
    </message>
    <message>
        <source>Sign in to receive a token and enable Raspberry Pi Connect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Raspberry Pi Imager requires elevated privileges to write to storage devices.</source>
        <translation>Raspberry Pi Imager richiede privilegi elevati per scrivere sui dispositivi di archiviazione.</translation>
    </message>
    <message>
        <source>Without this, you will encounter permission errors when writing images.</source>
        <translation>In caso contrario si verificheranno errori di autorizzazione durante la scrittura delle immagini.</translation>
    </message>
    <message>
        <source>You are not running as Administrator.

Please run as Administrator.</source>
        <translation>Non stai eseguendo come Amministratore.

Esegui come Amministratore.</translation>
    </message>
    <message>
        <source>You are not running as root.

Please run with elevated privileges: sudo %1</source>
        <translation>Non stai eseguendo come root.

Esegui con privilegi elevati: sudo %1</translation>
    </message>
    <message>
        <source>You are not running as root.

Click &quot;Install Authorization&quot; to set up automatic privilege elevation, or run manually with: sudo %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RemoteAccessStep</name>
    <message>
        <source>Enable SSH</source>
        <translation>Abilita SSH</translation>
    </message>
    <message>
        <source>Use password authentication</source>
        <translation>Usa autenticazione con password</translation>
    </message>
    <message>
        <source>Use public key authentication</source>
        <translation>Usa autenticazione con chiave pubblica</translation>
    </message>
    <message>
        <source>Customisation: SSH authentication</source>
        <translation>Personalizzazione: Autenticazione SSH</translation>
    </message>
    <message>
        <source>Learn about SSH</source>
        <translation>Scopri di più su SSH</translation>
    </message>
    <message>
        <source>Configure SSH access</source>
        <translation>Configura accesso SSH</translation>
    </message>
    <message>
        <source>Authentication mechanism:</source>
        <translation>Meccanismo di autenticazione:</translation>
    </message>
    <message>
        <source>Enable secure shell access for remote command-line control of your Raspberry Pi</source>
        <translation>Abilita l&apos;accesso shell sicuro per il controllo remoto a riga di comando del tuo Raspberry Pi</translation>
    </message>
    <message>
        <source>Save SSH settings and continue to next customisation step</source>
        <translation>Salva impostazioni SSH e continua al passaggio successivo</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Allow SSH login using the username and password you configured in the previous step.</source>
        <translation>Consenti login SSH usando nome utente e password configurati nel passaggio precedente.</translation>
    </message>
    <message>
        <source>Allow SSH login using a cryptographic key pair instead of a password. More secure than password authentication.</source>
        <translation>Consenti login SSH usando una coppia di chiavi crittografica invece della password. Più sicuro della password.</translation>
    </message>
    <message>
        <source>Choose how you will authenticate when connecting to your Raspberry Pi via SSH. Password authentication uses the account credentials you configured. Public key authentication uses a cryptographic key pair and is more secure.</source>
        <translation>Scegli come autenticarti quando ti connetti via SSH al tuo Raspberry Pi. L&apos;autenticazione con password usa le credenziali dell&apos;account configurate. Quella con chiave pubblica usa una coppia di chiavi crittografica ed è più sicura.</translation>
    </message>
</context>
<context>
    <name>RepositoryDialog</name>
    <message>
        <source>Content Repository</source>
        <translation>Repository contenuti</translation>
    </message>
    <message>
        <source>Repository source:</source>
        <translation>Sorgente repository:</translation>
    </message>
    <message>
        <source>Use custom file</source>
        <translation>Usa file personalizzato</translation>
    </message>
    <message>
        <source>Please select a custom repository json file</source>
        <translation>Seleziona un file JSON di un repository personalizzato</translation>
    </message>
    <message>
        <source>Select Repository</source>
        <translation>Seleziona repository</translation>
    </message>
    <message>
        <source>Apply &amp; Restart</source>
        <translation>Applica &amp; Riavvia</translation>
    </message>
    <message>
        <source>Select custom repository</source>
        <translation>Seleziona repository personalizzato</translation>
    </message>
    <message>
        <source>Use custom URL</source>
        <translation>Usa URL personalizzato</translation>
    </message>
    <message>
        <source>Select a custom repository JSON file from your computer</source>
        <translation>Seleziona un file JSON di un repository personalizzato dal computer</translation>
    </message>
    <message>
        <source>Close the repository dialog without changing the content source</source>
        <translation>Chiudi la finestra senza cambiare la sorgente dei contenuti</translation>
    </message>
    <message>
        <source>Apply the new content repository and restart the wizard from the beginning</source>
        <translation>Applica il nuovo repository e riavvia la procedura dall&apos;inizio</translation>
    </message>
    <message>
        <source>Choose the source for operating system images</source>
        <translation>Scegli la sorgente per le immagini del sistema operativo</translation>
    </message>
    <message>
        <source>Use the official Raspberry Pi operating system repository</source>
        <translation>Usa il repository ufficiale dei sistemi operativi Raspberry Pi</translation>
    </message>
    <message>
        <source>Load operating system list from a JSON file on your computer</source>
        <translation>Carica l&apos;elenco dei sistemi operativi da un file JSON sul computer</translation>
    </message>
    <message>
        <source>Download operating system list from a custom web address</source>
        <translation>Scarica l&apos;elenco dei sistemi operativi da un indirizzo web personalizzato</translation>
    </message>
</context>
<context>
    <name>SecureBootCustomizationStep</name>
    <message>
        <source>Customisation: Secure Boot</source>
        <translation>Personalizzazione: Secure Boot</translation>
    </message>
    <message>
        <source>Configure secure boot image signing</source>
        <translation>Configura la firma dell&apos;immagine per Secure Boot</translation>
    </message>
    <message>
        <source>Save secure boot settings and continue to next customisation step</source>
        <translation>Salva le impostazioni di Secure Boot e continua al passaggio successivo</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Enable Secure Boot Signing</source>
        <translation>Abilita firma Secure Boot</translation>
    </message>
    <message>
        <source>Sign the boot partition with your RSA key to enable secure boot verification on Raspberry Pi</source>
        <translation>Firma la partizione di boot con la tua chiave RSA per abilitare la verifica Secure Boot su Raspberry Pi</translation>
    </message>
    <message>
        <source>Learn about Secure Boot</source>
        <translation>Scopri di più su Secure Boot</translation>
    </message>
    <message>
        <source>This will create boot.img and boot.sig files required for Raspberry Pi Secure Boot.</source>
        <translation>Questo creerà i file boot.img e boot.sig richiesti per Secure Boot di Raspberry Pi.</translation>
    </message>
    <message>
        <source>Public Key Fingerprint: %1</source>
        <translation>Fingerprint chiave pubblica: %1</translation>
    </message>
    <message>
        <source>(unavailable)</source>
        <translation>(non disponibile)</translation>
    </message>
    <message>
        <source>(unable to compute)</source>
        <translation>(impossibile calcolare)</translation>
    </message>
    <message>
        <source>RSA Private Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished">Cambia</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished">Seleziona</translation>
    </message>
    <message>
        <source>Select an RSA 2048-bit private key for signing boot images in secure boot mode</source>
        <translation type="unfinished">Seleziona una chiave privata RSA 2048-bit per firmare le immagini di avvio in modalità Secure Boot</translation>
    </message>
    <message>
        <source>Select RSA Private Key</source>
        <translation type="unfinished">Seleziona chiave privata RSA</translation>
    </message>
    <message>
        <source>PEM Files (*.pem);;All Files (*)</source>
        <translation type="unfinished">File PEM (*.pem);;Tutti i file (*)</translation>
    </message>
    <message>
        <source>Selected: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your boot partition will be signed using the selected RSA private key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select an RSA private key above to enable secure boot signing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PEM Files (*.pem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SshKeyManager</name>
    <message>
        <source>No SSH keys configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 SSH key configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 SSH keys configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide the list of SSH keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show the list of SSH keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH keys list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH key %1: %2, %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH key %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH key %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove SSH key: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove SSH key %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste key or click BROWSE to select file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH public key input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste an SSH public key here or use the browse button to select a key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select SSH Public Key</source>
        <translation type="unfinished">Seleziona chiave pubblica SSH</translation>
    </message>
    <message>
        <source>Add the entered SSH key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an SSH public key file to add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StorageSelectionStep</name>
    <message>
        <source>No storage devices found</source>
        <translation>Nessun dispositivo di archiviazione trovato</translation>
    </message>
    <message>
        <source>Mounted as %1</source>
        <translation>Montato come %1</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>Sola lettura</translation>
    </message>
    <message>
        <source>Select your storage device</source>
        <translation>Seleziona il dispositivo di archiviazione</translation>
    </message>
    <message>
        <source>Exclude system drives</source>
        <translation>Escludi le unità di sistema</translation>
    </message>
    <message>
        <source>Storage device list</source>
        <translation>Elenco dei dispositivi di archiviazione</translation>
    </message>
    <message>
        <source>No devices</source>
        <translation>Nessun dispositivo</translation>
    </message>
    <message>
        <source>1 device</source>
        <translation>1 dispositivo</translation>
    </message>
    <message>
        <source>%1 devices</source>
        <translation>%1 dispositivi</translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select</source>
        <translation>Usa le frecce per navigare, Invio o Spazio per selezionare</translation>
    </message>
    <message>
        <source>All visible devices are read-only.
Try connecting a new device, or uncheck
&apos;Exclude system drives&apos; below.</source>
        <translation>Tutti i dispositivi visibili sono in sola lettura.
Prova a collegare un nuovo dispositivo o deseleziona
&apos;Escludi le unità di sistema&apos;.</translation>
    </message>
    <message>
        <source>All devices are read-only.
Please connect a writable storage device.</source>
        <translation>Tutti i dispositivi sono in sola lettura.
Collega un dispositivo di archiviazione scrivibile.</translation>
    </message>
    <message>
        <source>All devices are hidden by the filter.
Uncheck &apos;Exclude system drives&apos; below
to show system drives.</source>
        <translation>Tutti i dispositivi sono nascosti dal filtro.
Deseleziona &apos;Escludi le unità di sistema&apos;
per visualizzare le unità di sistema.</translation>
    </message>
    <message>
        <source>No storage devices found. Please connect a storage device to continue.</source>
        <translation>Nessun dispositivo di archiviazione trovato. Collega un dispositivo per continuare.</translation>
    </message>
    <message>
        <source>When checked, system drives are hidden from the list. Uncheck to show all drives including system drives.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid storage devices are currently available. All visible devices are read-only. Try connecting a new storage device, or uncheck &apos;Exclude system drives&apos; to show hidden system drives.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid storage devices are currently available. All devices are read-only. Please connect a writable storage device to continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid storage devices are currently available. Uncheck &apos;Exclude system drives&apos; to show hidden system drives, or connect a new storage device.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateAvailableDialog</name>
    <message>
        <source>Update available</source>
        <translation>Aggiornamento disponibile</translation>
    </message>
    <message>
        <source>There is a newer version of Imager available. Would you like to visit the website to download it?</source>
        <translation>È disponibile una nuova versione di Imager. Vuoi visitare il sito web per scaricarla?</translation>
    </message>
    <message>
        <source>Continue using the current version of Raspberry Pi Imager</source>
        <translation>Continua a usare la versione corrente di Raspberry Pi Imager</translation>
    </message>
    <message>
        <source>Open the Raspberry Pi website in your browser to download the latest version</source>
        <translation>Apri il sito web di Raspberry Pi nel browser per scaricare l&apos;ultima versione</translation>
    </message>
</context>
<context>
    <name>UserCustomizationStep</name>
    <message>
        <source>Username:</source>
        <translation>Nome utente:</translation>
    </message>
    <message>
        <source>Enter password</source>
        <translation>Inserisci password</translation>
    </message>
    <message>
        <source>Confirm password:</source>
        <translation>Conferma password:</translation>
    </message>
    <message>
        <source>Re-enter password</source>
        <translation>Reinserisci password</translation>
    </message>
    <message>
        <source>The username must be lowercase and contain only letters, numbers, underscores, and hyphens.</source>
        <translation>Il nome utente deve essere in minuscolo e contenere solo lettere, numeri, underscore e trattini.</translation>
    </message>
    <message>
        <source>Customisation: Choose username</source>
        <translation>Personalizzazione: Scegli nome utente</translation>
    </message>
    <message>
        <source>Saved (hidden) — leave blank to keep</source>
        <translation>Salvata (nascosta) — lascia vuoto per mantenere</translation>
    </message>
    <message>
        <source>Re-enter to change password</source>
        <translation>Reinserisci per cambiare password</translation>
    </message>
    <message>
        <source>Create a user account for your Raspberry Pi</source>
        <translation>Crea un account utente per il tuo Raspberry Pi</translation>
    </message>
    <message>
        <source>Enter your username</source>
        <translation>Inserisci il nome utente</translation>
    </message>
    <message>
        <source>Save user account settings and continue to next customisation step</source>
        <translation>Salva impostazioni account e continua al passaggio successivo</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Enter a username for your Raspberry Pi account. The username must be lowercase and contain only letters, numbers, underscores, and hyphens.</source>
        <translation>Inserisci un nome utente per l&apos;account Raspberry Pi. Deve essere in minuscolo e contenere solo lettere, numeri, underscore e trattini.</translation>
    </message>
    <message>
        <source>Enter a new password for this account, or leave blank to keep the previously saved password.</source>
        <translation>Inserisci una nuova password per questo account, oppure lascia vuoto per mantenere quella precedente.</translation>
    </message>
    <message>
        <source>Enter a password for this account. You will need to re-enter it in the next field to confirm.</source>
        <translation>Inserisci una password per questo account. Dovrai reinserirla nel campo successivo per confermare.</translation>
    </message>
    <message>
        <source>Re-enter the new password to confirm, or leave blank to keep the previously saved password.</source>
        <translation>Reinserisci la nuova password per confermare, oppure lascia vuoto per mantenere quella precedente.</translation>
    </message>
    <message>
        <source>Re-enter the password to confirm it matches.</source>
        <translation>Reinserisci la password per confermare che corrisponda.</translation>
    </message>
</context>
<context>
    <name>WifiCustomizationStep</name>
    <message>
        <source>SSID:</source>
        <translation>SSID:</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation>Nome rete</translation>
    </message>
    <message>
        <source>Network password</source>
        <translation>Password rete</translation>
    </message>
    <message>
        <source>Hidden SSID</source>
        <translation>SSID nascosto</translation>
    </message>
    <message>
        <source>Customisation: Choose Wi‑Fi</source>
        <translation>Personalizzazione: Scegli Wi‑Fi</translation>
    </message>
    <message>
        <source>No password (open network)</source>
        <translation>Senza password (rete aperta)</translation>
    </message>
    <message>
        <source>Saved (hidden) — leave blank to keep</source>
        <translation>Salvata (nascosta) — lascia vuoto per mantenere</translation>
    </message>
    <message>
        <source>Secure network</source>
        <translation>Rete sicura</translation>
    </message>
    <message>
        <source>Configure Wi-Fi for a password-protected network with WPA2/WPA3 encryption</source>
        <translation>Configura Wi-Fi per una rete protetta da password con crittografia WPA2/WPA3</translation>
    </message>
    <message>
        <source>Open network</source>
        <translation>Rete aperta</translation>
    </message>
    <message>
        <source>Configure Wi-Fi for an unencrypted network without password protection</source>
        <translation>Configura Wi-Fi per una rete non crittografata senza protezione da password</translation>
    </message>
    <message>
        <source>Enter a password</source>
        <translation>Inserisci una password</translation>
    </message>
    <message>
        <source>Password is too short (min 8 characters)</source>
        <translation>Password troppo corta (min 8 caratteri)</translation>
    </message>
    <message>
        <source>Password is too long (max 63 characters)</source>
        <translation>Password troppo lunga (max 63 caratteri)</translation>
    </message>
    <message>
        <source>Password contains unsupported characters</source>
        <translation>La password contiene caratteri non supportati</translation>
    </message>
    <message>
        <source>Confirm password:</source>
        <translation>Conferma password:</translation>
    </message>
    <message>
        <source>Re-enter password</source>
        <translation>Reinserisci password</translation>
    </message>
    <message>
        <source>Save Wi-Fi settings and continue to next customisation step</source>
        <translation>Salva impostazioni Wi-Fi e continua al passaggio successivo</translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation>Torna al passaggio precedente</translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation>Salta tutte le personalizzazioni e procedi direttamente alla scrittura dell&apos;immagine</translation>
    </message>
    <message>
        <source>Enter the network name (SSID) of your Wi-Fi network. This is the name that appears when you search for available networks.</source>
        <translation>Inserisci il nome della rete (SSID) del tuo Wi-Fi. È il nome visualizzato quando cerchi le reti disponibili.</translation>
    </message>
    <message>
        <source>Enter a new Wi-Fi password, or leave blank to keep the previously saved password. Must be 8-63 characters or a 64-character hexadecimal key.</source>
        <translation>Inserisci una nuova password Wi-Fi, oppure lascia vuoto per mantenere quella precedente. Deve essere di 8-63 caratteri o una chiave esadecimale di 64 caratteri.</translation>
    </message>
    <message>
        <source>Enter your Wi-Fi network password. Must be 8-63 characters or a 64-character hexadecimal key. You will need to re-enter it in the next field to confirm.</source>
        <translation>Inserisci la password della rete Wi-Fi. Deve essere di 8-63 caratteri o una chiave esadecimale di 64 caratteri. Dovrai reinserirla nel campo successivo per confermare.</translation>
    </message>
    <message>
        <source>Re-enter the new Wi-Fi password to confirm, or leave blank to keep the previously saved password.</source>
        <translation>Reinserisci la nuova password Wi-Fi per confermare, oppure lascia vuoto per mantenere quella precedente.</translation>
    </message>
    <message>
        <source>Re-enter the Wi-Fi password to confirm it matches.</source>
        <translation>Reinserisci la password Wi-Fi per confermare che corrisponda.</translation>
    </message>
    <message>
        <source>Check this if your Wi-Fi network does not broadcast its name and requires manual SSID entry to connect.</source>
        <translation>Seleziona se la rete Wi-Fi non trasmette il nome e richiede l&apos;inserimento manuale dell&apos;SSID per connettersi.</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Le password non corrispondono</translation>
    </message>
    <message>
        <source>Re-enter to change password</source>
        <translation>Reinserisci per cambiare password</translation>
    </message>
</context>
<context>
    <name>WizardContainer</name>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>OS</translation>
    </message>
    <message>
        <source>Storage</source>
        <translation>Archiviazione</translation>
    </message>
    <message>
        <source>Writing</source>
        <translation>Scrittura</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <source>Customisation</source>
        <translation>Personalizzazione</translation>
    </message>
    <message>
        <source>Hostname</source>
        <translation>Hostname</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>Wi‑Fi</source>
        <translation>Wi‑Fi</translation>
    </message>
    <message>
        <source>Raspberry Pi Connect</source>
        <translation>Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>App Options</source>
        <translation>Opzioni app</translation>
    </message>
    <message>
        <source>Interfaces &amp; Features</source>
        <translation>Interfacce &amp; Funzionalità</translation>
    </message>
    <message>
        <source>Setup steps</source>
        <translation>Passaggi di configurazione</translation>
    </message>
    <message>
        <source>Localisation</source>
        <translation>Localizzazione</translation>
    </message>
    <message>
        <source>Remote access</source>
        <translation>Accesso remoto</translation>
    </message>
    <message>
        <source>Open application settings to configure sound alerts, auto-eject, telemetry, and content repository</source>
        <translation>Apri impostazioni applicazione per configurare avvisi sonori, espulsione automatica, telemetria e repository contenuti</translation>
    </message>
    <message>
        <source>Replace existing Raspberry Pi Connect token?</source>
        <translation>Sostituire il token Raspberry Pi Connect esistente?</translation>
    </message>
    <message>
        <source>A new Raspberry Pi Connect token was received that differs from your current one.

</source>
        <translation>È stato ricevuto un nuovo token Raspberry Pi Connect diverso da quello corrente.

</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing token?

</source>
        <translation>Vuoi sovrascrivere il token esistente?

</translation>
    </message>
    <message>
        <source>Replace token</source>
        <translation>Sostituisci token</translation>
    </message>
    <message>
        <source>Please wait…</source>
        <translation>Attendere…</translation>
    </message>
    <message>
        <source>Replace the current token with the newly received one</source>
        <translation>Sostituisci il token corrente con quello appena ricevuto</translation>
    </message>
    <message>
        <source>Keep existing</source>
        <translation>Mantieni esistente</translation>
    </message>
    <message>
        <source>Keep your current Raspberry Pi Connect token</source>
        <translation>Mantieni il token Raspberry Pi Connect corrente</translation>
    </message>
    <message>
        <source>Secure Boot</source>
        <translation>Secure Boot</translation>
    </message>
    <message>
        <source>Warning: Only overwrite the token if you initiated this action.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WizardStepBase</name>
    <message>
        <source>Next</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <source>Skip customisation</source>
        <translation>Salta personalizzazione</translation>
    </message>
</context>
<context>
    <name>WritingStep</name>
    <message>
        <source>Review your choices and write the image to the storage device</source>
        <translation>Rivedi le scelte e scrivi l&apos;immagine sul dispositivo di archiviazione</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Scrivi</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Riepilogo</translation>
    </message>
    <message>
        <source>Starting write process...</source>
        <translation>Avvio processo di scrittura...</translation>
    </message>
    <message>
        <source>You are about to ERASE all data on: %1</source>
        <translation>Stai per CANCELLARE tutti i dati su: %1</translation>
    </message>
    <message>
        <source>the storage device</source>
        <translation>il dispositivo di archiviazione</translation>
    </message>
    <message>
        <source>This action is PERMANENT and CANNOT be undone.</source>
        <translation>Questa azione è PERMANENTE e NON può essere annullata.</translation>
    </message>
    <message>
        <source>I understand, erase and write</source>
        <translation>Ho capito, cancella e scrivi</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Attendere...</translation>
    </message>
    <message>
        <source>Writing... %1%</source>
        <translation>Scrittura... %1%</translation>
    </message>
    <message>
        <source>Verifying... %1%</source>
        <translation>Verifica... %1%</translation>
    </message>
    <message>
        <source>Write completed successfully!</source>
        <translation>Scrittura completata con successo!</translation>
    </message>
    <message>
        <source>Write failed: %1</source>
        <translation>Scrittura fallita: %1</translation>
    </message>
    <message>
        <source>Customisations to apply:</source>
        <translation>Personalizzazioni da applicare:</translation>
    </message>
    <message>
        <source>Finalising...</source>
        <translation>Finalizzazione...</translation>
    </message>
    <message>
        <source>Write image</source>
        <translation>Scrivi immagine</translation>
    </message>
    <message>
        <source>Operating system:</source>
        <translation>Sistema operativo:</translation>
    </message>
    <message>
        <source>Cancel and return to the write summary without erasing the storage device</source>
        <translation>Annulla e torna al riepilogo senza cancellare il dispositivo</translation>
    </message>
    <message>
        <source>Confirm erasure and begin writing the image to the storage device</source>
        <translation>Conferma la cancellazione e inizia a scrivere l&apos;immagine sul dispositivo</translation>
    </message>
    <message>
        <source>Skip verification</source>
        <translation>Salta verifica</translation>
    </message>
    <message>
        <source>Cancel write</source>
        <translation>Annulla scrittura</translation>
    </message>
    <message>
        <source>Skip verification and finish the write process</source>
        <translation>Salta la verifica e termina il processo di scrittura</translation>
    </message>
    <message>
        <source>Cancel the write operation and return to the summary</source>
        <translation>Annulla l&apos;operazione di scrittura e torna al riepilogo</translation>
    </message>
    <message>
        <source>Continue to the completion screen</source>
        <translation>Continua alla schermata di completamento</translation>
    </message>
    <message>
        <source>Begin writing the image to the storage device. All existing data will be erased.</source>
        <translation>Inizia a scrivere l&apos;immagine sul dispositivo. Tutti i dati esistenti verranno cancellati.</translation>
    </message>
    <message>
        <source>Return to previous customization step</source>
        <translation>Torna al passaggio di personalizzazione precedente</translation>
    </message>
    <message>
        <source>Write progress</source>
        <translation>Progresso scrittura</translation>
    </message>
    <message>
        <source>Finalising…</source>
        <translation>Finalizzazione…</translation>
    </message>
    <message>
        <source>Write complete</source>
        <translation>Scrittura completata</translation>
    </message>
    <message>
        <source>customization</source>
        <translation>personalizzazione</translation>
    </message>
    <message>
        <source>customizations</source>
        <translation>personalizzazioni</translation>
    </message>
    <message>
        <source>Writing in progress — do not disconnect the storage device</source>
        <translation>Scrittura in corso — non scollegare il dispositivo di archiviazione</translation>
    </message>
    <message>
        <source>Please wait... %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Are you sure you want to quit?</source>
        <translation>Sei sicuro di voler uscire?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Format card as FAT32</source>
        <translation>Formatta scheda come FAT32</translation>
    </message>
    <message>
        <source>Use custom</source>
        <translation>Usa immagine personalizzata</translation>
    </message>
    <message>
        <source>Select a custom .img from your computer</source>
        <translation>Seleziona un file immagine .img personalizzato</translation>
    </message>
    <message>
        <source>Raspberry Pi Imager is still busy. Are you sure you want to quit?</source>
        <translation>Raspberry Pi Imager è ancora in esecuzione. Sei sicuro di voler uscire?</translation>
    </message>
    <message>
        <source>Storage device removed</source>
        <translation>Dispositivo di archiviazione rimosso</translation>
    </message>
    <message>
        <source>The storage device was removed while writing, so the operation was cancelled. Please reinsert the device or select a different one to continue.</source>
        <translation>Il dispositivo di archiviazione è stato rimosso durante la scrittura, quindi l&apos;operazione è stata annullata. Reinserisci il dispositivo o selezionane uno diverso per continuare.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Close the error dialog and continue</source>
        <translation>Chiudi la finestra di errore e continua</translation>
    </message>
    <message>
        <source>Close the storage removed notification and return to storage selection</source>
        <translation>Chiudi la notifica di rimozione e torna alla selezione del dispositivo</translation>
    </message>
    <message>
        <source>Return to Raspberry Pi Imager and continue the current operation</source>
        <translation>Torna a Raspberry Pi Imager e continua l&apos;operazione corrente</translation>
    </message>
    <message>
        <source>Force quit Raspberry Pi Imager and cancel the current write operation</source>
        <translation>Forza l&apos;uscita da Raspberry Pi Imager e annulla l&apos;operazione di scrittura corrente</translation>
    </message>
    <message>
        <source>Raspberry Pi Imager %1</source>
        <translation>Raspberry Pi Imager %1</translation>
    </message>
    <message>
        <source>Insufficient Permissions</source>
        <translation>Permessi insufficienti</translation>
    </message>
    <message>
        <source>Error message explaining why elevated privileges are required</source>
        <translation>Messaggio di errore che spiega perché sono richiesti privilegi elevati</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Exit Raspberry Pi Imager - you must restart with elevated privileges to write images</source>
        <translation>Esci da Raspberry Pi Imager - devi riavviare con privilegi elevati per scrivere immagini</translation>
    </message>
    <message>
        <source>Install Authorization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install system authorization to allow Raspberry Pi Imager to run with elevated privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Performance Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JSON files (*.json)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation type="unfinished">Tutti i file (*)</translation>
    </message>
</context>
</TS>
